@@ -4,10 +4,10 @@
      *         TMP1, TMP2)
 
         DOUBLE PRECISION TOPBLK,ARRAY,BOTBLK,B,X,TMP1,TMP2
-        INTEGER PIVOT(1),nrwtop,NRWBLK,NCLBLK,NRWBOT,N,NOVRLP,NBLOKS
+        INTEGER PIVOT(*),nrwtop,NRWBLK,NCLBLK,NRWBOT,N,NOVRLP,NBLOKS
 	      INTEGER I, IFLAG, rB, cB
-        DIMENSION TOPBLK(NRWTOP,1),ARRAY(NRWBLK,NCLBLK,1),
-     *          BOTBLK(NRWBOT,1),B(rB,cB),X(N,cB),TMP1(*),TMP2(*)
+        DIMENSION TOPBLK(NRWTOP,*),ARRAY(NRWBLK,NCLBLK,*),
+     *          BOTBLK(NRWBOT,*),B(rB,cB),X(N,cB),TMP1(*),TMP2(*)
 
 
          DO J = 1,N
@@ -176,10 +176,10 @@ C
 C*************************************************************************
 C
         DOUBLE PRECISION TOPBLK,ARRAY,BOTBLK,B,X
-        INTEGER PIVOT(1),nrwtop,NRWBLK,NCLBLK,NRWBOT,N,NOVRLP,NBLOKS
+        INTEGER PIVOT(*),nrwtop,NRWBLK,NCLBLK,NRWBOT,N,NOVRLP,NBLOKS
 	  INTEGER IFLAG
-        DIMENSION TOPBLK(NRWTOP,1),ARRAY(NRWBLK,NCLBLK,1),
-     *          BOTBLK(NRWBOT,1),B(1),X(1)
+        DIMENSION TOPBLK(NRWTOP,*),ARRAY(NRWBLK,NCLBLK,*),
+     *          BOTBLK(NRWBOT,*),B(*),X(*)
         CALL CRDCMP(N,TOPBLK,NRWTOP,NOVRLP,ARRAY,NRWBLK,NCLBLK,NBLOKS,
      *          BOTBLK,NRWBOT,PIVOT,IFLAG)
         IF(IFLAG.NE.0)RETURN
@@ -265,12 +265,12 @@ C
         DOUBLE PRECISION TOPBLK,ARRAY,BOTBLK
         DOUBLE PRECISION ROWMAX,ROWPIV,ROWMLT,COLMAX,COLPIV
         DOUBLE PRECISION SWAP,COLMLT,PIVMAX,ZERO,TEMPIV
-        INTEGER PIVOT(1),NRWTOP,NRWBLK,NCLBLK,NRWBOT,IFLAG
+        INTEGER PIVOT(*),NRWTOP,NRWBLK,NCLBLK,NRWBOT,IFLAG
 	  INTEGER NRWTP1,NROWEL,NRWEL1,NVRLP0,NOVRLP,N,NBLOKS
 	  INTEGER I,IPLUS1,IPVT,J,L,INCR,K,KPLUS1,JPLUS1,JMINN,LOOP
 	  INTEGER INCRJ,IPLUSN,INCRN,IRWBLK,IPVBLK,JRWBLK
-        DIMENSION TOPBLK(NRWTOP,1),ARRAY(NRWBLK,NCLBLK,1),
-     *          BOTBLK(NRWBOT,1)
+        DIMENSION TOPBLK(NRWTOP,*),ARRAY(NRWBLK,NCLBLK,*),
+     *          BOTBLK(NRWBOT,*)
         DATA ZERO/0.0D0/
 C
 C***************************************************************
@@ -774,14 +774,14 @@ C***************************************************************
 C
         DOUBLE PRECISION TOPBLK,ARRAY,BOTBLK,X,B
         DOUBLE PRECISION DOTPRD,XJ,XINCRJ,BINCRJ,SWAP
-        INTEGER PIVOT(1),NRWTOP,NRWBLK,NCLBLK,NRWBOT
+        INTEGER PIVOT(*),NRWTOP,NRWBLK,NCLBLK,NRWBOT
 	  INTEGER NRWTP1,NRWBK1,NVRLP1,NOVRLP,NRWTP0,NRWBT1
 	  INTEGER NROWEL,NRWEL1,NVRLP0,NBLKS1,NBLOKS,NBKTOP
 	  INTEGER J,LOOP,I,INCR,K,INCRTP,INCRJ,INCRI,JPIVOT
 	  INTEGER JRWTOP,LL,NRWBTL,L,L1,IPLUSN,INCRN,IPVTN
 	  INTEGER NRWELL,IPVTI
-        DIMENSION TOPBLK(NRWTOP,1),ARRAY(NRWBLK,NCLBLK,1),
-     *          BOTBLK(NRWBOT,1),B(1),X(1)
+        DIMENSION TOPBLK(NRWTOP,*),ARRAY(NRWBLK,NCLBLK,*),
+     *          BOTBLK(NRWBOT,*),B(*),X(*)
 C
 C***************************************************************
 C
